@@ -36,7 +36,7 @@
 import os
 import time
 import hashlib
-from subprocess import Popen, PIPE
+from twisted.internet.utils import getProcessOutputAndValue
 
 from deluge.log import LOG as log
 from deluge.plugins.pluginbase import CorePluginBase
@@ -110,15 +110,23 @@ class Core(CorePluginBase):
 
         log.debug("[execute] Running commands for %s", event)
 
+        def log_error(result, command):
+            (stdout, stderr, exit_code) = result
+            if exit_code:
+                log.warn("[execute] command '%s' failed with exit code %d", command, exit_code)
+                if stdout:
+                    log.warn("[execute] stdout: %s", stdout)
+                if stderr:
+                    log.warn("[execute] stderr: %s", stderr)
+
         # Go through and execute all the commands
         for command in self.config["commands"]:
             if command[EXECUTE_EVENT] == event:
                 command = os.path.expandvars(command[EXECUTE_COMMAND])
                 command = os.path.expanduser(command)
                 log.debug("[execute] running %s", command)
-                p = Popen([command, torrent_id, torrent_name, save_path], stdin=PIPE, stdout=PIPE, stderr=PIPE)
-                if p.wait() != 0:
-                    log.warn("Execute command failed with exit code %d", p.returncode)
+                d = getProcessOutputAndValue(command, (torrent_id, torrent_name, save_path), env=os.environ)
+                d.addCallback(log_error, command)
 
     def disable(self):
         self.config.save()
