@@ -261,7 +261,7 @@ class Screen(CursesStdIO):
         Updates the lines based on the`:attr:lines` based on the `:attr:display_lines_offset`
         attribute and the status bars.
         """
-        self.stdscr.clear()
+        self.stdscr.erase()
 
         # Update the status bars
         self.add_string(0, self.topbar)
