@@ -196,7 +196,16 @@ class AddTorrentDialog(component.Component):
 
         for filename in filenames:
             # Convert the path to unicode
-            filename = unicode(filename)
+            log.debug("Adding torrent from file: %s (%s)", filename, type(filename))
+            try:
+                filename = unicode(filename, "utf8")
+            except UnicodeDecodeError:
+                # Try 'latin-1' if filename has originated from http
+                log.debug("Decode with 'utf-8' failed trying 'latin-1'")
+                filename = unicode(filename, "latin-1")
+            except TypeError:
+                # Already unicode
+                pass
 
             # Get the torrent data from the torrent file
             try:
@@ -547,6 +556,7 @@ class AddTorrentDialog(component.Component):
         chooser.set_transient_for(self.dialog)
         chooser.set_select_multiple(True)
         chooser.set_property("skip-taskbar-hint", True)
+        chooser.set_local_only(False)
 
         # Add .torrent and * file filters
         file_filter = gtk.FileFilter()
